@@ -1,14 +1,16 @@
 """This is the “nester.py" module, and it provides one function called print_lol() 
 which prints lists that may or may not include nested lists."""
 
-def print_lol(the_list, level):
+def print_lol(the_list, indent=False, level=0):
 	"""This function takes a positional argument called “the_list", which is any Python list (of, possibly, nested lists).
 	Each data item in the provided list is (recursively) printed to the screen on its own line.
-	A second argument called “level" is used to insert tab-stops when a nested list is encountered."""
+	A second argument called "indent" determines whether the printing is indented or not.
+	A third argument called “level" is used to insert tab-stops when a nested list is encountered."""
 	for each_item in the_list:
 		if (isinstance(each_item, list)):
-			print_lol(each_item, level+1)
+			print_lol(each_item, indent, level+1)
 		else:   
-			for tabstop in range(level):
-				print("\t", end='')
+			if indent:
+				for tabstop in range(level):
+					print("\t", end='')
 			print(each_item)
\ No newline at end of file
